import viz
import vizact
import vizshape

viz.setMultiSample(4)
viz.fov(60)
viz.go()

viz.MainView.setPosition([0,1.8,-20])

torso = viz.addChild('obj/robotTorso.obj')
tbox = torso.getBoundingBox()

shoulders = viz.addChild('obj/robotShoulders.obj', parent=torso)
sbox = shoulders.getBoundingBox()
shoulders.setCenter(sbox.center)

upperArmJoint = viz.addChild('obj/robotUpperArmJoint.obj', parent=shoulders)
uajbox = upperArmJoint.getBoundingBox()
upperArmJoint.setCenter(uajbox.center)
upperArm = viz.addChild('obj/robotUpperArm.obj', parent=upperArmJoint)

lowerArmJoint = viz.addChild('obj/robotLowerArmJoint.obj', parent=upperArm)
lajbox = lowerArmJoint.getBoundingBox()
lowerArmJoint.setCenter(lajbox.center)
lowerArm = viz.addChild('obj/robotLowerArm.obj', parent=lowerArmJoint)

class KeyframeInterp:
	def __init__ (self):	#initialize all class variables
		self.time = 0
		self.nParams = 0
		self.nFrames = 0
		self.keyframes = []
		self.params = []
		self.keyindex = 1
		self.timestep = 0
		
	def linearInterpolation(self):	
		t0 = self.keyframes[self.keyindex-1][0]
		t1 = self.keyframes[self.keyindex][0]
		t = (self.time - t0) / (t1-t0)
		for i in  range(1, self.nParams+1):
			a = self.keyframes[self.keyindex-1][i]
			b = self.keyframes[self.keyindex][i]
			self.params[i] = (1-t)*a + t*b
			
	def advanceTime(self):
		self.time = self.time+self.timestep
		keytime = self.keyframes[self.keyindex][0]
		if(self.time > keytime):
			self.keyindex = self.keyindex + 1
		if(self.keyindex >= self.nFrames):
			self.keyindex = 1
			self.time = 0

def RobotWave():
	robot.advanceTime()
	robot.linearInterpolation()
	upperArmJoint.setAxisAngle([0,0,1,robot.params[1]])
	lowerArmJoint.setAxisAngle([0,0,1,robot.params[2]])

robot = KeyframeInterp()
robot.nParams = 2		
for i in range(0, robot.nParams+1):
	robot.params.append(0)	
robot.keyframes.append([0,0,0])
robot.keyframes.append([1.6,90,60])
robot.keyframes.append([1.9,90,90])
robot.keyframes.append([2.1,90,60])
robot.keyframes.append([2.6,90,90])
robot.keyframes.append([3.1,90,60])
robot.keyframes.append([4.1,0,0])
robot.nFrames = 7
robot.timestep = 0.02
				
vizact.ontimer(0, RobotWave)
	